@@ -12,7 +12,7 @@ function (x, na.rm = TRUE)
         } else {
     
     skewer <- rep(NA,dim(x)[2])
-    mx <- colMeans(x,na.rm=na.rm)
+    if (is.matrix(x)) {mx <- colMeans(x,na.rm=na.rm)} else {mx <- mean(x,na.rm=na.rm)}
     sdx <- sd(x,na.rm=na.rm)
     for (i in 1:dim(x)[2]) {
     skewer[i] <- sum((x[,i] - mx[i])^3,  na.rm = na.rm)/((length(x[,i]) - sum(is.na(x[,i]))) * sdx[i]^3)
